==> alloy-ui-3.0.1.jar: META-INF/resources/webjars/alloy-ui/3.0.1/src/aui-widget/HISTORY.md <==
# AUI Widget

> Documentation and test modifications are not included in this changelog. For more details, see [full commit history](https://github.com/liferay/alloy-ui/commits/master/src/aui-widget).

## @VERSION@

## [3.0.0](https://github.com/liferay/alloy-ui/releases/tag/3.0.0)

* [AUI-1305](https://issues.liferay.com/browse/AUI-1305) Make aui-image-gallery responsive
* [AUI-1655](https://issues.liferay.com/browse/AUI-1655) WidgetTrigger doesn't work with `tap` event
* [AUI-1526](https://issues.liferay.com/browse/AUI-1526) Create a menu module
* [AUI-1310](https://issues.liferay.com/browse/AUI-1310) Make aui-tooltip responsive
* [AUI-1318](https://issues.liferay.com/browse/AUI-1318) Make aui-image-viewer responsive
* [AUI-1299](https://issues.liferay.com/browse/AUI-1299) Make aui-carousel responsive
* [AUI-1341](https://issues.liferay.com/browse/AUI-1341) Rename variable _eventHandles of Widget Trigger to _triggerEventHandles
* [AUI-1153](https://issues.liferay.com/browse/AUI-1153) Create Bootstrap's Dropdown module
* [AUI-1174](https://issues.liferay.com/browse/AUI-1174) Validate source code with JSHint
* [AUI-1178](https://issues.liferay.com/browse/AUI-1178) Enable use a function as value to widget position
* [AUI-1098](https://issues.liferay.com/browse/AUI-1098) Upgrade to Bootstrap 3
* [AUI-1253](https://issues.liferay.com/browse/AUI-1253) Fix modal header buttons pushing the header content down

## [2.5.0](https://github.com/liferay/alloy-ui/releases/tag/2.5.0)

* [AUI-1178](https://issues.liferay.com/browse/AUI-1178) Enable use a function as value to widget position
* [AUI-1237](https://issues.liferay.com/browse/AUI-1237) The value of cssClass attribute always comes from the config, ignoring the value assigned
* [AUI-1179](https://issues.liferay.com/browse/AUI-1179) Enable use a single value to set show and hide delay on transition
* [AUI-1163](https://issues.liferay.com/browse/AUI-1163) Remove unnecessary constants
* [AUI-1146](https://issues.liferay.com/browse/AUI-1146) Add attribute delay
* [AUI-1162](https://issues.liferay.com/browse/AUI-1162) Decouple animation logic from tooltip-base to a new widget called Widget Transition

==> alloy-ui-3.0.2.jar: META-INF/resources/webjars/alloy-ui/3.0.2/src/aui-widget/HISTORY.md <==
# AUI Widget

> Documentation and test modifications are not included in this changelog. For more details, see [full commit history](https://github.com/liferay/alloy-ui/commits/master/src/aui-widget).

## @VERSION@

* [AUI-2021](https://issues.liferay.com/browse/AUI-2021) AUI-Popover should choose the best position according to its constrain element

## [3.0.1](https://github.com/liferay/alloy-ui/releases/tag/3.0.1)

No changes.

## [3.0.0](https://github.com/liferay/alloy-ui/releases/tag/3.0.0)

* [AUI-1305](https://issues.liferay.com/browse/AUI-1305) Make aui-image-gallery responsive
* [AUI-1655](https://issues.liferay.com/browse/AUI-1655) WidgetTrigger doesn't work with `tap` event
* [AUI-1526](https://issues.liferay.com/browse/AUI-1526) Create a menu module
* [AUI-1310](https://issues.liferay.com/browse/AUI-1310) Make aui-tooltip responsive
* [AUI-1318](https://issues.liferay.com/browse/AUI-1318) Make aui-image-viewer responsive
* [AUI-1299](https://issues.liferay.com/browse/AUI-1299) Make aui-carousel responsive
* [AUI-1341](https://issues.liferay.com/browse/AUI-1341) Rename variable _eventHandles of Widget Trigger to _triggerEventHandles
* [AUI-1153](https://issues.liferay.com/browse/AUI-1153) Create Bootstrap's Dropdown module
* [AUI-1174](https://issues.liferay.com/browse/AUI-1174) Validate source code with JSHint
* [AUI-1178](https://issues.liferay.com/browse/AUI-1178) Enable use a function as value to widget position
* [AUI-1098](https://issues.liferay.com/browse/AUI-1098) Upgrade to Bootstrap 3
* [AUI-1253](https://issues.liferay.com/browse/AUI-1253) Fix modal header buttons pushing the header content down

## [2.5.0](https://github.com/liferay/alloy-ui/releases/tag/2.5.0)

* [AUI-1178](https://issues.liferay.com/browse/AUI-1178) Enable use a function as value to widget position
* [AUI-1237](https://issues.liferay.com/browse/AUI-1237) The value of cssClass attribute always comes from the config, ignoring the value assigned
* [AUI-1179](https://issues.liferay.com/browse/AUI-1179) Enable use a single value to set show and hide delay on transition
* [AUI-1163](https://issues.liferay.com/browse/AUI-1163) Remove unnecessary constants
* [AUI-1146](https://issues.liferay.com/browse/AUI-1146) Add attribute delay
* [AUI-1162](https://issues.liferay.com/browse/AUI-1162) Decouple animation logic from tooltip-base to a new widget called Widget Transition
